The nmrstarlib API Reference
=============================

.. automodule:: nmrstarlib

.. automodule:: nmrstarlib.nmrstarlib
   :member-order: bysource
   :members:
   :special-members:
   :private-members:

.. automodule:: nmrstarlib.bmrblex

.. autoclass:: bmrblex
   :member-order: bysource
   :members:
   :special-members:
   :private-members:

.. automodule:: nmrstarlib.converter

.. autoclass:: Converter
   :member-order: bysource
   :members:
   :special-members:
   :private-members:

.. automodule:: nmrstarlib.csviewer
   :member-order: bysource
   :members:
   :special-members:
   :private-members:
